==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildStatusOutputFluent<A extends io.fabric8.openshift.api.model.BuildStatusOutputFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.BuildStatusOutputTo getTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputTo buildTo();
  public A withTo(io.fabric8.openshift.api.model.BuildStatusOutputTo to);
  public java.lang.Boolean hasTo();
  public A withNewTo(java.lang.String imageDigest);
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item);
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item);
  public interface ToNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.BuildStatusOutputToFluent<io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<N>>{
    public N and();
    public N endTo();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildStatusOutputFluent<A extends io.fabric8.openshift.api.model.BuildStatusOutputFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.BuildStatusOutputTo getTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputTo buildTo();
  public A withTo(io.fabric8.openshift.api.model.BuildStatusOutputTo to);
  public java.lang.Boolean hasTo();
  public A withNewTo(java.lang.String imageDigest);
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> withNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item);
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewTo();
  public io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<A> editOrNewToLike(io.fabric8.openshift.api.model.BuildStatusOutputTo item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ToNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.BuildStatusOutputToFluent<io.fabric8.openshift.api.model.BuildStatusOutputFluent.ToNested<N>>{
    public N and();
    public N endTo();
    
  }
  
}
